#!/usr/bin/env python
# encoding: utf-8
#
# Copyright  (c) 2014 deanishe@deanishe.net
#
# MIT Licence. See http://opensource.org/licenses/MIT
#
# Created on 2014-02-25
#

"""Variables required by more than one script."""

import os
import shutil

# ----------------------------------------------------------------------
# Result display
# ----------------------------------------------------------------------
DECIMAL_PLACES = int(os.getenv('DECIMAL_PLACES') or '2')
CURRENCY_DECIMAL_PLACES = int(os.getenv('CURRENCY_DECIMAL_PLACES') or
                              str(DECIMAL_PLACES))
DECIMAL_SEPARATOR = os.getenv('DECIMAL_SEPARATOR') or '.'
THOUSANDS_SEPARATOR = os.getenv('THOUSANDS_SEPARATOR') or ''

DYNAMIC_DECIMALS = os.getenv('DYNAMIC_DECIMALS', '') not in ('', '0')
COPY_UNIT = os.getenv('COPY_UNIT', '') not in ('', '0')


# ----------------------------------------------------------------------
# Currency settings
# ----------------------------------------------------------------------
# API key for openexchangerates.org
OPENX_APP_KEY = os.getenv('APP_KEY') or None
# Update interval (default 6 hours)
CURRENCY_CACHE_AGE = int(os.getenv('UPDATE_INTERVAL') or '360') * 60

CURRENCY_CACHE_NAME = 'exchange_rates'
REFERENCE_CURRENCY = 'USD'
OPENX_API_URL = 'https://openexchangerates.org/api/latest.json?app_id={}'
XRA_API_URL = 'https://api.exchangerate-api.com/v4/latest/{}'
CRYPTO_COMPARE_BASE_URL = (
    'https://min-api.cryptocompare.com/data/price?fsym={}&tsyms={}')
SYMBOLS_PER_REQUEST = 20
USER_AGENT = 'Alfred Convert/{}'.format(os.getenv('alfred_workflow_version'))
NOKEY_FILENAME = 'nokey'

# ----------------------------------------------------------------------
# Unit definition files
# ----------------------------------------------------------------------
DEFAULT_UNIT_DEFINITIONS = os.path.join(os.path.dirname(__file__),
                                        'pint/default_en.txt')
CUSTOM_DEFINITIONS_FILENAME = 'unit_definitions.txt'
BUILTIN_UNIT_DEFINITIONS = os.path.join(os.path.dirname(__file__),
                                        CUSTOM_DEFINITIONS_FILENAME)

ACTIVE_CURRENCIES_FILENAME = 'active_currencies.txt'

CURRENCIES = {
    u'AED': u'United Arab Emirates Dirham',
    u'AFN': u'Afghan Afghani',
    u'ALL': u'Albanian Lek',
    u'AMD': u'Armenian Dram',
    u'ANG': u'Netherlands Antillean Guilder',
    u'AOA': u'Angolan Kwanza',
    u'ARS': u'Argentine Peso',
    u'AUD': u'Australian Dollar',
    u'AWG': u'Aruban Florin',
    u'AZN': u'Azerbaijani Manat',
    u'BAM': u'Bosnia-Herzegovina Convertible Mark',
    u'BBD': u'Barbadian Dollar',
    u'BDT': u'Bangladeshi Taka',
    u'BGN': u'Bulgarian Lev',
    u'BHD': u'Bahraini Dinar',
    u'BIF': u'Burundian Franc',
    u'BMD': u'Bermudan Dollar',
    u'BND': u'Brunei Dollar',
    u'BOB': u'Bolivian Boliviano',
    u'BRL': u'Brazilian Real',
    u'BSD': u'Bahamian Dollar',
    u'BTC': u'Bitcoin',
    u'BTN': u'Bhutanese Ngultrum',
    u'BWP': u'Botswanan Pula',
    u'BYN': u'Belarusian Ruble',
    u'BYR': u'Belarusian Ruble (pre-2016)',
    u'BZD': u'Belize Dollar',
    u'CAD': u'Canadian Dollar',
    u'CDF': u'Congolese Franc',
    u'CHF': u'Swiss Franc',
    u'CLF': u'Chilean Unit of Account (UF)',
    u'CLP': u'Chilean Peso',
    u'CNH': u'Chinese Yuan (Offshore)',
    u'CNY': u'Chinese Renminbi',
    u'COP': u'Colombian Peso',
    u'CRC': u'Costa Rican Colón',
    u'CUC': u'Cuban Convertible Peso',
    u'CUP': u'Cuban Peso',
    u'CVE': u'Cape Verdean Escudo',
    u'CZK': u'Czech Koruna',
    u'DJF': u'Djiboutian Franc',
    u'DKK': u'Danish Krone',
    u'DOP': u'Dominican Peso',
    u'DZD': u'Algerian Dinar',
    u'EEK': u'Estonian Kroon',
    u'EGP': u'Egyptian Pound',
    u'ERN': u'Eritrean Nakfa',
    u'ETB': u'Ethiopian Birr',
    u'EUR': u'Euro',
    u'FJD': u'Fijian Dollar',
    u'FKP': u'Falkland Islands Pound',
    u'GBP': u'British Pound Sterling',
    u'GEL': u'Georgian Lari',
    u'GGP': u'Guernsey Pound',
    u'GHS': u'Ghanaian Cedi',
    u'GIP': u'Gibraltar Pound',
    u'GMD': u'Gambian Dalasi',
    u'GNF': u'Guinean Franc',
    u'GTQ': u'Guatemalan Quetzal',
    u'GYD': u'Guyanaese Dollar',
    u'HKD': u'Hong Kong Dollar',
    u'HNL': u'Honduran Lempira',
    u'HRK': u'Croatian Kuna',
    u'HTG': u'Haitian Gourde',
    u'HUF': u'Hungarian Forint',
    u'IDR': u'Indonesian Rupiah',
    u'ILS': u'Israeli Shekel',
    u'IMP': u'Manx pound',
    u'INR': u'Indian Rupee',
    u'IQD': u'Iraqi Dinar',
    u'IRR': u'Iranian Rial',
    u'ISK': u'Icelandic Krona',
    u'JEP': u'Jersey Pound',
    u'JMD': u'Jamaican Dollar',
    u'JOD': u'Jordanian Dinar',
    u'JPY': u'Japanese Yen',
    u'KES': u'Kenyan Shilling',
    u'KGS': u'Kyrgystani Som',
    u'KHR': u'Cambodian Riel',
    u'KMF': u'Comorian Franc',
    u'KPW': u'North Korean Won',
    u'KRW': u'South Korean Won',
    u'KWD': u'Kuwaiti Dinar',
    u'KYD': u'Cayman Islands Dollar',
    u'KZT': u'Kazakhstani Tenge',
    u'LAK': u'Laotian Kip',
    u'LBP': u'Lebanese Pound',
    u'LKR': u'Sri Lankan Rupee',
    u'LRD': u'Liberian Dollar',
    u'LSL': u'Lesotho Loti',
    u'LYD': u'Libyan Dinar',
    u'MAD': u'Moroccan Dirham',
    u'MDL': u'Moldovan Leu',
    u'MGA': u'Malagasy Ariary',
    u'MKD': u'Macedonian Denar',
    u'MMK': u'Myanma Kyat',
    u'MNT': u'Mongolian Tugrik',
    u'MOP': u'Macanese Pataca',
    u'MRO': u'Mauritanian Ouguiya (pre-2018)',
    u'MRU': u'Mauritanian Ouguiya',
    u'MTL': u'Maltese Lira',
    u'MUR': u'Mauritian Rupee',
    u'MVR': u'Maldivian Rufiyaa',
    u'MWK': u'Malawian Kwacha',
    u'MXN': u'Mexican Peso',
    u'MYR': u'Malaysian Ringgit',
    u'MZN': u'Mozambican Metical',
    u'NAD': u'Namibian Dollar',
    u'NGN': u'Nigerian Naira',
    u'NIO': u'Nicaraguan Córdoba',
    u'NOK': u'Norwegian Krone',
    u'NPR': u'Nepalese Rupee',
    u'NZD': u'New Zealand Dollar',
    u'OMR': u'Omani Rial',
    u'PAB': u'Panamanian Balboa',
    u'PEN': u'Peruvian Nuevo Sol',
    u'PGK': u'Papua New Guinean Kina',
    u'PHP': u'Philippine Peso',
    u'PKR': u'Pakistani Rupee',
    u'PLN': u'Polish Zloty',
    u'PYG': u'Paraguayan Guarani',
    u'QAR': u'Qatari Rial',
    u'RON': u'Romanian Leu',
    u'RSD': u'Serbian Dinar',
    u'RUB': u'Russian Ruble',
    u'RWF': u'Rwandan Franc',
    u'SAR': u'Saudi Riyal',
    u'SBD': u'Solomon Islands Dollar',
    u'SCR': u'Seychellois Rupee',
    u'SDG': u'Sudanese Pound',
    u'SEK': u'Swedish Krona',
    u'SGD': u'Singapore Dollar',
    u'SHP': u'Saint Helena Pound',
    u'SLL': u'Sierra Leonean Leone',
    u'SOS': u'Somali Shilling',
    u'SRD': u'Surinamese Dollar',
    u'SSP': u'South Sudanese Pound',
    u'STN': u'São Tomé and Príncipe Dobra',
    u'SVC': u'Salvadoran Colón',
    u'SYP': u'Syrian Pound',
    u'SZL': u'Swazi Lilangeni',
    u'THB': u'Thai Baht',
    u'TJS': u'Tajikistani Somoni',
    u'TMT': u'Turkmenistani Manat',
    u'TND': u'Tunisian Dinar',
    u'TOP': u'Tongan Paʻanga',
    u'TRY': u'Turkish Lira',
    u'TTD': u'Trinidad and Tobago Dollar',
    u'TWD': u'New Taiwan Dollar',
    u'TZS': u'Tanzanian Shilling',
    u'UAH': u'Ukrainian Hryvnia',
    u'UGX': u'Ugandan Shilling',
    u'USD': u'US Dollar',
    u'UYU': u'Uruguayan Peso',
    u'UZS': u'Uzbekistan Som',
    u'VEF': u'Venezuelan Bolívar Fuerte',
    u'VND': u'Vietnamese Dong',
    u'VUV': u'Vanuatu Vatu',
    u'WST': u'Samoan Tala',
    u'XAF': u'CFA Franc BEAC',
    u'XAG': u'Silver (troy ounce)',
    u'XAU': u'Gold (troy ounce)',
    u'XCD': u'East Caribbean Dollar',
    u'XDR': u'Special Drawing Rights',
    u'XOF': u'CFA Franc BCEAO',
    u'XPD': u'Palladium Ounce',
    u'XPF': u'CFP Franc',
    u'XPT': u'Platinum Ounce',
    u'YER': u'Yemeni Rial',
    u'ZAR': u'South African Rand',
    u'ZMW': u'Zambian Kwacha',
}

CRYPTO_CURRENCIES = {
    # Pint doesn't support units that start with a digit
    # u'007': u'007 coin',
    # u'1337': u'1337',
    # u'1CR': u'1Credit',
    # u'1ST': u'FirstBlood',
    # u'2015': u'2015 coin',
    # u'2BACCO': u'2BACCO Coin',
    # u'2GIVE': u'2GiveCoin',
    # u'32BIT': u'32Bitcoin',
    # u'365': u'365Coin',
    # u'404': u'404Coin',
    # u'42': u'42 Coin',
    # u'4CHN': u'ChanCoin',
    # u'611': u'SixEleven',
    # u'808': u'808',
    # u'888': u'Octocoin',
    # u'8BIT': u'8BIT Coin',
    # u'8BT': u'8 Circuit Studios',
    u'ABC': u'AB-Chain',
    u'ABY': u'ArtByte',
    u'AC': u'Asia Coin',
    u'ACC': u'AdCoin',
    u'ACES': u'AcesCoin',
    u'ACID': u'AcidCoin',
    u'ACN': u'AvonCoin',
    u'ACOIN': u'ACoin',
    u'ACP': u'Anarchists Prime',
    u'ADA': u'Cardano',
    u'ADC': u'AudioCoin',
    u'ADCN': u'Asiadigicoin',
    u'ADL': u'Adelphoi',
    u'ADN': u'Aiden',
    u'ADST': u'Adshares',
    u'ADT': u'AdToken',
    u'ADX': u'AdEx',
    u'ADZ': u'Adzcoin',
    u'AE': u'Aeternity',
    u'AEC': u'AcesCoin',
    u'AEON': u'AeonCoin',
    u'AERO': u'Aero Coin',
    u'AGRS': u'Agoras Token',
    u'AGS': u'Aegis',
    u'AHT': u'Ahoolee',
    u'AIB': u'AdvancedInternetBlock',
    u'AIR': u'AirToken',
    # u'AIR*': u'Aircoin',
    u'ALC': u'Arab League Coin',
    u'ALEX': u'Alexandrite',
    u'ALF': u'AlphaCoin',
    u'ALIS': u'ALISmedia',
    u'ALN': u'AlienCoin',
    u'AM': u'AeroMe',
    u'AMB': u'Ambrosus',
    u'AMBER': u'AmberCoin',
    u'AMC': u'AmericanCoin',
    u'AMIS': u'AMIS',
    u'AMP': u'Synereo',
    u'AMS': u'Amsterdam Coin',
    u'AMY': u'Amygws',
    u'ANAL': u'AnalCoin',
    u'ANC': u'Anoncoin',
    u'AND': u'AndromedaCoin',
    u'ANT': u'Aragon',
    u'ANTI': u'Anti Bitcoin',
    u'APC': u'AlpaCoin',
    u'APEX': u'ApexCoin',
    u'APT': u'Aptcoin',
    u'APX': u'Apx',
    u'ARB': u'Arbit Coin',
    # u'ARC*': u'ArcticCoin',
    u'ARCH': u'ArchCoin',
    u'ARCO': u'AquariusCoin',
    u'ARDR': u'Ardor',
    u'ARENA': u'Arena',
    u'ARG': u'Argentum',
    u'ARGUS': u'ArgusCoin',
    u'ARI': u'AriCoin',
    u'ARK': u'ARK',
    u'ARM': u'Armory Coin',
    u'ARPA': u'ArpaCoin',
    u'ASAFE': u'Allsafe',
    u'ASN': u'Ascension Coin',
    u'AST': u'AirSwap',
    # u'AST*': u'Astral',
    u'ATB': u'ATB coin',
    u'ATCC': u'ATC Coin',
    u'ATL': u'ATLANT',
    u'ATM': u'Autumncoin',
    u'ATMS': u'Atmos',
    u'ATOM': u'Atomic Coin',
    u'ATS': u'Authorship',
    u'ATX': u'ArtexCoin',
    u'AUR': u'Aurora Coin',
    u'AURS': u'Aureus',
    u'AV': u'Avatar Coin',
    u'AVT': u'AventCoin',
    u'AXIOM': u'Axiom Coin',
    u'AXR': u'AXRON',
    u'B3': u'B3 Coin',
    u'B@': u'BankCoin',
    u'BAC': u'BitalphaCoin',
    u'BAN': u'Babes and Nerds',
    u'BAR': u'TBIS token',
    u'BASH': u'LuckChain',
    u'BAT': u'Basic Attention Token',
    u'BAY': u'BitBay',
    u'BBCC': u'BaseballCardCoin',
    u'BBR': u'Boolberry',
    u'BCAP': u'Blockchain Capital',
    u'BCCOIN': u'BitConnect Coin',
    u'BCF': u'BitcoinFast',
    u'BCH': u'Bitcoin Cash / BCC',
    u'BCN': u'ByteCoin',
    u'BCR': u'BitCredit',
    u'BCX': u'BattleCoin',
    u'BCY': u'BitCrystals',
    u'BELA': u'BelaCoin',
    u'BEN': u'Benjamins',
    u'BENJI': u'BenjiRolls',
    u'BERN': u'BERNcash',
    u'BEST': u'BestChain',
    u'BET': u'BetaCoin',
    u'BET*': u'DAO.casino',
    u'BFX': u'BitFinex Tokens',
    u'BHC': u'BighanCoin',
    u'BIC': u'Bikercoins',
    u'BIGUP': u'BigUp',
    u'BIOB': u'BioBar',
    u'BIOS': u'BiosCrypto',
    u'BIP': u'BipCoin',
    u'BIS': u'Bismuth',
    u'BIT16': u'16BitCoin',
    u'BITB': u'BitBean',
    u'BITCNY': u'bitCNY',
    u'BITOK': u'BitOKX',
    u'BITS': u'BitstarCoin',
    u'BITUSD': u'bitUSD',
    u'BITZ': u'Bitz Coin',
    u'BLAS': u'BlakeStar',
    u'BLAZR': u'BlazerCoin',
    u'BLC': u'BlakeCoin',
    u'BLITZ': u'BlitzCoin',
    u'BLK': u'BlackCoin',
    u'BLOCK': u'BlockNet',
    u'BLRY': u'BillaryCoin',
    u'BLU': u'BlueCoin',
    u'BLUE': u'Ethereum Blue',
    u'BLX': u'Blockchain Index',
    u'BM': u'BitMoon',
    u'BMC': u'Blackmoon Crypto',
    u'BNB': u'Binance Coin',
    # u'BNB*': u'Boats and Bitches',
    u'BNC': u'Benjacoin',
    u'BNT': u'Bancor Network Token',
    u'BNX': u'BnrtxCoin',
    u'BOAT': u'Doubloon',
    # u'BOB': u'Bob Coin',
    u'BOLI': u'BolivarCoin',
    u'BOMB': u'BombCoin',
    u'BON': u'BonesCoin',
    u'BOOM': u'BOOM Coin',
    u'BOS': u'BOScoin',
    u'BOSON': u'BosonCoin',
    u'BOSS': u'BitBoss',
    u'BOST': u'BoostCoin',
    u'BQ': u'Bitqy',
    u'BQC': u'BQCoin',
    u'BQX': u'Bitquence',
    u'BRAIN': u'BrainCoin',
    u'BRAT': u'Brat',
    u'BRDD': u'BeardDollars',
    u'BRIT': u'BritCoin',
    u'BRK': u'BreakoutCoin',
    u'BRO': u'Bitradio',
    u'BRONZ': u'BitBronze',
    u'BRX': u'Breakout Stake',
    u'BS': u'BlackShadowCoin',
    u'BSC': u'BowsCoin',
    # u'BSD': u'BitSend',
    u'BST': u'BitStone',
    u'BSTAR': u'Blackstar',
    u'BSTK': u'BattleStake',
    u'BSTY': u'GlobalBoost',
    u'BTA': u'Bata',
    u'BTB': u'BitBar',
    u'BTC': u'Bitcoin',
    u'BTCD': u'BitcoinDark',
    u'BTCR': u'BitCurrency',
    u'BTCRY': u'BitCrystal',
    u'BTCS': u'Bitcoin Scrypt',
    u'BTD': u'Bitcloud',
    u'BTE': u'ByteCoin',
    u'BTG': u'Bitcoin Gold',
    # u'BTG*': u'BitGem',
    u'BTLC': u'BitLuckCoin',
    u'BTM': u'BitMark',
    # u'BTM*': u'Bytom',
    u'BTMI': u'BitMiles',
    u'BTPL': u'Bitcoin Planet',
    u'BTQ': u'BitQuark',
    u'BTS': u'Bitshares',
    u'BTTF': u'Coin to the Future',
    u'BTX': u'Bitcore',
    # u'BTX*': u'BitcoinTX',
    u'BTZ': u'BitzCoin',
    u'BUCKS': u'SwagBucks',
    u'BUK': u'CryptoBuk',
    u'BURST': u'BurstCoin',
    u'BUZZ': u'BuzzCoin',
    u'BVC': u'BeaverCoin',
    u'BXC': u'Bitcedi',
    u'BXT': u'BitTokens',
    u'BYC': u'ByteCent',
    u'C2': u'Coin.2',
    u'CAB': u'CabbageUnit',
    u'CACH': u'Cachecoin',
    u'CAG': u'Change',
    u'CAIX': u'CAIx',
    u'CALC': u'CaliphCoin',
    u'CAM': u'Camcoin',
    u'CANN': u'CannabisCoin',
    u'CAP': u'BottleCaps',
    u'CARBON': u'Carboncoin',
    u'CASH': u'CashCoin',
    u'CAT': u'BlockCAT',
    # u'CAT*': u'BitClave',
    u'CBD': u'CBD Crystals',
    u'CBX': u'CryptoBullion',
    u'CC': u'CyberCoin',
    u'CCC': u'CCCoin',
    u'CCN': u'CannaCoin',
    u'CCRB': u'CryptoCarbon',
    u'CCX': u'CoolDarkCoin',
    u'CDN': u'Canada eCoin',
    u'CDT': u'CoinDash',
    u'CDX': u'Cryptodex',
    u'CELL': u'SolarFarm',
    u'CESC': u'Crypto Escudo',
    u'CETI': u'CETUS Coin',
    u'CF': u'Californium',
    u'CFC': u'CoffeeCoin',
    u'CFI': u'Cofound.it',
    u'CFT': u'CryptoForecast',
    u'CGA': u'Cryptographic Anomaly',
    u'CHA': u'Charity Coin',
    u'CHAO': u'23 Skidoo',
    u'CHASH': u'CleverHash',
    u'CHAT': u'ChatCoin',
    u'CHC': u'ChainCoin',
    u'CHESS': u'ChessCoin',
    u'CHIEF': u'TheChiefCoin',
    u'CHILD': u'ChildCoin',
    u'CHIP': u'Chip',
    u'CHOOF': u'ChoofCoin',
    u'CIN': u'CinderCoin',
    u'CINNI': u'CINNICOIN',
    u'CIR': u'CircuitCoin',
    u'CIRC': u'CryptoCircuits',
    u'CJ': u'CryptoJacks',
    u'CJC': u'CryptoJournal',
    u'CKC': u'Clockcoin',
    u'CLAM': u'CLAMS',
    u'CLICK': u'Clickcoin',
    u'CLINT': u'Clinton',
    u'CLOAK': u'CloakCoin',
    u'CLR': u'CopperLark',
    u'CLUB': u' ClubCoin',
    u'CLUD': u'CludCoin',
    u'CLV': u'CleverCoin',
    u'CMC': u'CosmosCoin',
    u'CMP': u'Compcoin',
    u'CMPCO': u'CampusCoin',
    u'CMT': u'CometCoin',
    u'CNC': u'ChinaCoin',
    u'CND': u'Cindicator',
    u'CNL': u'ConcealCoin',
    u'CNMT': u'Coinomat',
    u'CNO': u'Coino',
    # u'CNT': u'Centurion',
    u'CNX': u'Cryptonex',
    u'COB': u'Cobinhood',
    u'COC': u'Community Coin',
    u'COE': u'CoEval',
    u'COIN': u'Coin',
    u'COLX': u'ColossusCoinXT',
    u'COMM': u'Community Coin',
    u'CON': u'Paycon',
    u'COOL': u'CoolCoin',
    u'COR': u'Corion',
    u'CORAL': u'CoralPay',
    u'CORE': u'Core Group Asset',
    u'COSS': u'COSS',
    u'COV': u'Covesting',
    # u'COV*': u'CovenCoin',
    u'COVAL': u'Circuits of Value',
    u'COX': u'CobraCoin',
    u'CPC': u'CapriCoin',
    u'CQST': u'ConquestCoin',
    u'CRAB': u'CrabCoin',
    u'CRACK': u'CrackCoin',
    u'CRAFT': u'Craftcoin',
    u'CRAIG': u'CraigsCoin',
    u'CRAVE': u'CraveCoin',
    u'CRBIT': u'Creditbit ',
    # u'CRC': u'CraftCoin',
    u'CRE': u'Credits',
    u'CREA': u'CreativeChain',
    u'CREVA': u'Creva Coin',
    u'CRM': u'Cream',
    u'CRNK': u'CrankCoin',
    u'CRPS': u'CryptoPennies',
    u'CRW': u'Crown Coin',
    u'CRX': u'ChronosCoin',
    u'CRYPT': u'CryptCoin',
    u'CS': u'CryptoSpots',
    u'CSC': u'CasinoCoin',
    u'CSH': u'CashOut',
    u'CSMIC': u'Cosmic',
    u'CSNO': u'BitDice',
    u'CTC': u'CarterCoin',
    u'CTIC': u'Coinmatic',
    u'CTO': u'Crypto',
    u'CTR': u'Centra',
    u'CTX': u'CarTaxi',
    u'CUBE': u'DigiCube',
    u'CURE': u'Curecoin',
    u'CVC': u'Civic',
    u'CWXT': u'CryptoWorldXToken',
    u'CXC': u'CheckCoin',
    u'CXT': u'Coinonat',
    u'CYC': u'ConSpiracy Coin ',
    u'CYG': u'Cygnus',
    u'CYP': u'CypherPunkCoin',
    u'CYT': u'Cryptokenz',
    u'CZC': u'Crazy Coin',
    u'DANK': u'DarkKush',
    u'DAR': u'Darcrus',
    u'DARK': u'Dark',
    u'DAS': u'DAS',
    u'DASH': u'DigitalCash',
    u'DAT': u'Datum',
    u'DB': u'DarkBit',
    u'DBG': u'Digital Bullion Gold',
    u'DBIC': u'DubaiCoin',
    u'DBIX': u'DubaiCoin',
    u'DBTC': u'DebitCoin',
    u'DCC': u'DarkCrave',
    u'DCK': u'DickCoin',
    u'DCN': u'Dentacoin',
    u'DCR': u'Decred',
    u'DCRE': u'DeltaCredits',
    u'DCT': u'Decent',
    u'DCY': u'Dinastycoin',
    u'DDF': u'Digital Developers Fund',
    u'DEA': u'Degas Coin',
    u'DEEP': u'Deep Gold',
    u'DEM': u'eMark',
    u'DENT': u'Dent',
    u'DES': u'Destiny',
    u'DETH': u'DarkEther',
    u'DEUR': u'DigiEuro',
    u'DFT': u'Draftcoin',
    u'DGB': u'DigiByte',
    u'DGC': u'DigiCoin',
    u'DGD': u'Digix DAO',
    u'DGDC': u'DarkGold',
    u'DGMS': u'Digigems',
    u'DGORE': u'DogeGoreCoin',
    u'DICE': u'Etheroll',
    u'DIEM': u'CarpeDiemCoin',
    u'DIGS': u'Diggits',
    u'DIME': u'DimeCoin',
    u'DISK': u'Dark Lisk',
    u'DKC': u'DarkKnightCoin',
    u'DLC': u'DollarCoin',
    u'DLISK': u'Dlisk',
    u'DLT': u'Agrello Delta',
    u'DMD': u'Diamond',
    u'DNET': u'Darknet',
    u'DNR': u'Denarius',
    u'DNT': u'district0x',
    u'DOGE': u'Dogecoin',
    u'DOGED': u'DogeCoinDark',
    u'DOGETH': u'EtherDoge',
    u'DOPE': u'DopeCoin',
    u'DOT': u'Dotcoin',
    u'DOV': u'DonationCoin',
    u'DP': u'DigitalPrice',
    u'DPAY': u'DelightPay',
    u'DRA': u'DraculaCoin',
    u'DRACO': u'DT Token',
    u'DRKC': u'DarkCash',
    u'DRKT': u'DarkTron',
    u'DRM8': u'Dream8Coin',
    u'DROP': u'FaucetCoin',
    u'DRT': u'DomRaider',
    u'DRZ': u'Droidz',
    u'DSB': u'DarkShibe',
    u'DSH': u'Dashcoin',
    u'DT': u'DarkToken',
    u'DTB': u'Databits',
    u'DTC': u'DayTrader Coin',
    u'DTT': u'DreamTeam Token',
    u'DUB': u'DubCoin',
    u'DUCK': u'DuckDuckCoin',
    u'DUO': u'ParallelCoin',
    u'DUX': u'DuxCoin',
    u'DVC': u'DevCoin',
    u'DYN': u'Dynamic',
    u'EA': u'EagleCoin',
    u'EAC': u'EarthCoin',
    u'EAGS': u'EagsCoin',
    u'EB3': u'EB3coin',
    u'EBET': u'EthBet',
    u'EBS': u'EbolaShare',
    u'EBTC': u'eBTC',
    u'EC': u'Eclipse',
    u'ECASH': u'Ethereum Cash',
    u'ECO': u'ECOcoin',
    u'ECOB': u'EcoBit',
    u'EDC': u'EducoinV',
    u'EDDIE': u'Eddie coin',
    u'EDG': u'Edgeless',
    u'EDGE': u'EdgeCoin',
    u'EDO': u'Eidoo',
    u'EDR': u'E-Dinar Coin',
    u'EDRC': u'EDRCoin',
    u'EFL': u'E-Gulden',
    u'EFYT': u'Ergo',
    u'EGC': u'EverGreenCoin',
    u'EGG': u'EggCoin',
    u'EGO': u'EGOcoin',
    u'EKN': u'Elektron',
    u'EKO': u'EkoCoin',
    u'ELC': u'Elacoin',
    u'ELE': u'Elementrem',
    u'ELITE': u'EthereumLite',
    u'ELIX': u'Elixir',
    u'ELM': u'Elements',
    u'ELS': u'Elysium',
    u'ELTC2': u'eLTC',
    u'EMB': u'EmberCoin',
    u'EMC': u'Emercoin',
    u'EMC2': u'Einsteinium',
    u'EMD': u'Emerald',
    u'EMPC': u'EmporiumCoin',
    u'EMT': u'EasyMine',
    u'ENE': u'EneCoin',
    u'ENG': u'Enigma',
    u'ENJ': u'Enjin Coin',
    u'ENRG': u'EnergyCoin',
    u'ENT': u'Eternity',
    u'ENTER': u'EnterCoin (ENTER)',
    u'EOC': u'EveryonesCoin',
    u'EOS': u'EOS',
    u'EPY': u'Empyrean',
    u'EQ': u'EQUI',
    u'EQM': u'Equilibrium Coin',
    u'EQT': u'EquiTrader',
    u'EQUAL': u'EqualCoin',
    u'ERC': u'EuropeCoin',
    u'ERR': u'ErrorCoin',
    u'ERY': u'Eryllium',
    u'ESP': u'Espers',
    u'ETBS': u'EthBits',
    u'ETC': u'Ethereum Classic',
    u'ETG': u'Ethereum Gold',
    u'ETH': u'Ethereum ',
    u'ETHD': u'Ethereum Dark',
    u'ETHS': u'EthereumScrypt',
    u'ETN': u'Electroneum',
    u'ETP': u'Metaverse',
    u'ETT': u'EncryptoTel',
    u'EUC': u'Eurocoin',
    u'EVC': u'Eventchain',
    u'EVENT': u'Event Token',
    u'EVIL': u'EvilCoin',
    u'EVX': u'Everex',
    u'EXB': u'ExaByte (EXB)',
    u'EXCL': u'Exclusive Coin',
    u'EXE': u'ExeCoin',
    u'EXIT': u'ExitCoin',
    u'EXP': u'Expanse',
    u'EZC': u'EZCoin',
    u'F16': u'F16Coin',
    u'FAIR': u'FairCoin',
    u'FAME': u'FameCoin',
    u'FAZZ': u'FazzCoin',
    u'FC': u'Facecoin',
    u'FC2': u'Fuel2Coin',
    u'FCN': u'FantomCoin ',
    u'FCS': u'CryptoFocus',
    u'FCT': u'Factoids',
    u'FDC': u'FoodCoin',
    u'FFC': u'FireflyCoin',
    u'FGZ': u'Free Game Zone',
    u'FIBRE': u'FIBRE',
    u'FIND': u'FindCoin',
    u'FIRE': u'FireCoin',
    u'FIRST': u'FirstCoin',
    u'FIST': u'FistBump',
    u'FIT': u'Fitcoin',
    u'FJC': u'FujiCoin',
    u'FLASH': u'FLASH coin',
    u'FLDC': u'Folding Coin',
    u'FLIK': u'FLiK',
    u'FLO': u'FlorinCoin',
    u'FLT': u'FlutterCoin',
    u'FLVR': u'FlavorCoin',
    u'FLX': u'Flash',
    u'FLY': u'FlyCoin',
    u'FONZ': u'FonzieCoin',
    u'FOREX': u'ForexCoin',
    u'FRAC': u'FractalCoin',
    u'FRAZ': u'FrazCoin',
    u'FRC': u'FireRoosterCoin',
    u'FRE': u'FreeCoin',
    u'FRK': u'Franko',
    u'FRN': u'Francs',
    u'FRST': u'FirstCoin',
    u'FRWC': u'Frankywillcoin',
    u'FSC2': u'FriendshipCoin',
    u'FSN': u'Fusion',
    u'FST': u'FastCoin',
    u'FTC': u'FeatherCoin',
    u'FTP': u'FuturePoints',
    u'FUCK': u'Fuck Token',
    u'FUEL': u'Etherparty',
    u'FUN': u'FunFair',
    u'FUNC': u'FunCoin',
    u'FUTC': u'FutCoin',
    u'FUZZ': u'Fuzzballs',
    u'FX': u'FCoin',
    u'FYN': u'FundYourselfNow',
    u'GAIA': u'GAIA Platform',
    u'GAKH': u'GAKHcoin',
    u'GAM': u'Gambit coin',
    u'GAME': u'Gamecredits',
    u'GAP': u'Gapcoin',
    u'GAS': u'Gas',
    u'GAY': u'GayCoin',
    u'GB': u'GoldBlocks',
    u'GBIT': u'GravityBit',
    u'GBRC': u'GBR Coin',
    u'GBT': u'GameBetCoin',
    u'GBYTE': u'Byteball',
    u'GCC': u'GuccioneCoin',
    u'GCN': u'GCoin',
    u'GCR': u'Global Currency Reserve',
    u'GDC': u'GrandCoin',
    u'GEMZ': u'Gemz Social',
    u'GEN': u'Genstake',
    u'GEO': u'GeoCoin',
    u'GGS': u'Gilgam',
    u'GHC': u'GhostCoin',
    u'GHOUL': u'Ghoul Coin',
    # u'GHS': u'Giga Hash',
    u'GIFT': u'GiftNet',
    u'GIG': u'GigCoin',
    u'GIM': u'Gimli',
    u'GIVE': u'GiveCoin',
    u'GIZ': u'GIZMOcoin',
    u'GLC': u'GlobalCoin',
    u'GLD': u'GoldCoin',
    u'GLOBE': u'Global',
    u'GLX': u'GalaxyCoin',
    u'GLYPH': u'GlyphCoin',
    u'GMC': u'Gridmaster',
    u'GML': u'GameLeagueCoin',
    u'GMX': u'Goldmaxcoin',
    u'GNJ': u'GanjaCoin V2',
    u'GNO': u'Gnosis',
    u'GNT': u'Golem Network Token',
    u'GOAT': u'Goat',
    u'GOLOS': u'Golos',
    u'GOOD': u'GoodCoin',
    u'GOON': u'Goonies',
    u'GOT': u'Giotto Coin',
    u'GOTX': u'GothicCoin',
    u'GP': u'GoldPieces',
    u'GPL': u'Gold Pressed Latinum',
    u'GPU': u'GPU Coin',
    u'GRAM': u'Gram Coin',
    u'GRAV': u'Graviton',
    u'GRC': u'GridCoin',
    u'GRE': u'GreenCoin',
    u'GREXIT': u'GrexitCoin',
    u'GRF': u'Graft Network',
    u'GRID': u'GridPay',
    u'GRM': u'GridMaster',
    u'GROW': u'GrownCoin',
    u'GRS': u'Groestlcoin ',
    u'GRT': u'Grantcoin',
    u'GRW': u'GrowthCoin',
    u'GRWI': u'Growers International',
    u'GSM': u'GSM Coin',
    u'GSX': u'GlowShares',
    u'GSY': u'GenesysCoin',
    u'GUE': u'GuerillaCoin',
    u'GUNS': u'GeoFunders',
    u'GUP': u'Guppy',
    u'GXC': u'Gx Coin',
    # u'GXC*': u'GenXCoin',
    u'HAC': u'Hackspace Capital',
    u'HAL': u'Halcyon',
    u'HALLO': u'Halloween Coin',
    u'HAMS': u'HamsterCoin',
    u'HAZE': u'HazeCoin',
    u'HBN': u'HoboNickels',
    u'HBT': u'Hubiit',
    u'HCC': u'HappyCreatorCoin ',
    u'HDG': u'Hedge Token',
    u'HEAT': u'Heat Ledger',
    u'HEDG': u'Hedgecoin',
    u'HEEL': u'HeelCoin',
    u'HGT': u'Hello Gold',
    u'HILL': u'President Clinton',
    u'HIRE': u'HireMatch',
    u'HKG': u'Hacker Gold',
    u'HMP': u'HempCoin',
    u'HMQ': u'Humaniq',
    u'HNC': u'Hellenic Coin',
    u'HODL': u'HOdlcoin',
    u'HONEY': u'Honey',
    u'HPC': u'HappyCoin',
    u'HRB': u'Harbour DAO',
    u'HSP': u'Horse Power',
    u'HSR': u'Hshare',
    u'HTC': u'Hitcoin',
    u'HTML5': u'HTML Coin',
    u'HUC': u'HunterCoin',
    u'HUGE': u'BigCoin',
    u'HUSH': u'Hush',
    u'HVC': u'HeavyCoin',
    u'HVCO': u'High Voltage Coin',
    u'HVN': u'Hive',
    u'HXX': u'HexxCoin',
    u'HYP': u'Hyperstake',
    u'HYPER': u'HyperCoin',
    u'HZ': u'Horizon',
    u'HZT': u'HazMatCoin',
    u'I0C': u'I0coin',
    u'IBANK': u'iBankCoin',
    u'ICASH': u'ICASH',
    u'ICB': u'IceBergCoin',
    u'ICE': u'iDice',
    u'ICN': u'Iconomi',
    u'ICOB': u'Icobid',
    u'ICON': u'Iconic',
    u'ICOS': u'ICOBox',
    u'ICX': u'ICON Project',
    u'IEC': u'IvugeoEvolutionCoin',
    u'IFC': u'Infinite Coin',
    u'IFLT': u'InflationCoin',
    u'IFT': u'InvestFeed',
    u'IGNIS': u'Ignis',
    u'ILC': u'ILCoin',
    u'IML': u'IMMLA',
    u'IMPCH': u'Impeach',
    u'IMPS': u'Impulse Coin',
    u'IMS': u'Independent Money System',
    u'IMX': u'Impact',
    u'IN': u'InCoin',
    u'INC': u'Incrementum',
    u'INCNT': u'Incent',
    u'INCP': u'InceptionCoin',
    u'IND': u'Indorse',
    u'INFX': u'Influxcoin',
    u'INPAY': u'InPay',
    u'INSANE': u'InsaneCoin',
    u'INSN': u'Insane Coin',
    u'INV': u'Invictus',
    u'INXT': u'Internxt',
    u'IOC': u'IOCoin',
    u'ION': u'Ionomy',
    u'IOP': u'Internet of People',
    u'IOT': u'IOTA',
    u'IOU': u'IOU1',
    u'IPC': u'ImperialCoin',
    u'ISL': u'IslaCoin',
    u'ITT': u'Intelligent Trading Technologies',
    u'IVZ': u'InvisibleCoin',
    u'IW': u'iWallet',
    u'IWT': u'IwToken',
    u'IXC': u'IXcoin',
    u'IXT': u'iXledger',
    u'J': u'JoinCoin',
    u'JANE': u'JaneCoin',
    u'JBS': u'JumBucks Coin',
    u'JIF': u'JiffyCoin',
    u'JIO': u'JIO Token',
    u'JKC': u'JunkCoin',
    u'JNS': u'Janus',
    u'JOBS': u'JobsCoin',
    u'JOK': u'JokerCoin',
    u'JPC': u'JackPotCoin',
    u'JUDGE': u'JudgeCoin',
    u'JWL': u'Jewels',
    u'KARM': u'Karmacoin',
    u'KAT': u'KATZcoin',
    u'KAYI': u'Kayı',
    u'KC': u'Kernalcoin',
    u'KDC': u'Klondike Coin',
    u'KED': u'Klingon Empire Darsek',
    u'KEY': u'KeyCoin',
    u'KGC': u'KrugerCoin',
    u'KICK': u'KickCoin',
    u'KIN': u'Kin',
    u'KING': u'King93',
    u'KLC': u'KiloCoin',
    u'KMD': u'Komodo',
    u'KNC': u'Kyber Network',
    # u'KNC*': u'Khancoin',
    u'KOBO': u'KoboCoin',
    u'KOLION': u'Kolion',
    u'KORE': u'Kore',
    u'KR': u'Krypton',
    u'KRAK': u'Kraken',
    u'KRB': u'Karbowanec',
    u'KRC': u'KRCoin',
    u'KRONE': u'Kronecoin',
    u'KTK': u'KryptCoin',
    u'KUBO': u'KubosCoin',
    u'KURT': u'Kurrent',
    u'KUSH': u'KushCoin',
    u'LA': u'LAToken',
    u'LAB': u'CoinWorksCoin',
    u'LANA': u'LanaCoin',
    u'LAT': u'Latium',
    u'LAZ': u'Lazarus',
    u'LBC': u'LBRY Credits',
    u'LBTC': u'LiteBitcoin',
    u'LC': u'Lutetium Coin',
    u'LDOGE': u'LiteDoge',
    u'LEA': u'LeaCoin',
    u'LEMON': u'LemonCoin',
    u'LENIN': u'LeninCoin',
    u'LEO': u'LEOcoin',
    u'LEPEN': u'LePenCoin',
    u'LFC': u'BigLifeCoin',
    u'LGBTQ': u'LGBTQoin',
    u'LGD': u'Legends Cryptocurrency',
    u'LIMX': u'LimeCoinX',
    u'LINDA': u'Linda',
    u'LINK': u'ChainLink',
    u'LINX': u'Linx',
    u'LIR': u'Let it Ride',
    u'LIV': u'LiviaCoin',
    u'LK7': u'Lucky7Coin',
    u'LKK': u'Lykke',
    u'LKY': u'LuckyCoin',
    u'LMC': u'LomoCoin',
    u'LNK': u'Ethereum.Link',
    u'LOC': u'Loco',
    u'LOG': u'Wood Coin',
    u'LOOK': u'LookCoin',
    u'LQD': u'Liquid',
    u'LRC': u'Loopring',
    u'LSD': u'LightSpeedCoin',
    u'LSK': u'Lisk',
    u'LTB': u'Litebar ',
    u'LTBC': u'LTBCoin',
    u'LTC': u'Litecoin',
    u'LTCD': u'LitecoinDark',
    u'LTCR': u'LiteCreed',
    u'LTCX': u'LitecoinX',
    u'LTD': u'Limited Coin',
    u'LTH': u'Lathaan',
    u'LTS': u'Litestar Coin',
    u'LUCKY': u'LuckyBlocks (LUCKY)',
    u'LUN': u'Lunyr',
    u'LUX': u'LUXCoin',
    u'LVG': u'Leverage Coin',
    u'LXC': u'LibrexCoin',
    u'LYB': u'LyraBar',
    u'LYC': u'LycanCoin',
    u'M1': u'SupplyShock',
    u'MAC': u'MachineCoin',
    # u'MAD': u'SatoshiMadness',
    u'MAID': u'MaidSafe Coin',
    u'MANA': u'Decentraland',
    u'MAPC': u'MapCoin',
    u'MAR': u'MarijuanaCoin',
    u'MARS': u'MarsCoin ',
    u'MARV': u'Marvelous',
    u'MARX': u'MarxCoin',
    u'MARYJ': u'MaryJane Coin',
    # u'MAT*': u'Manet Coin',
    u'MAX': u'MaxCoin',
    u'MAY': u'Theresa May Coin',
    u'MBI': u'Monster Byte Inc',
    u'MBIT': u'Mbitbooks',
    u'MBRS': u'Embers',
    u'MCAP': u'MCAP',
    u'MCAR': u'MasterCar',
    u'MCI': u'Musiconomi',
    u'MCN': u'MonetaVerde',
    u'MCO': u'Monaco',
    u'MCRN': u'MacronCoin',
    u'MDA': u'Moeda',
    u'MDC': u'MedicCoin',
    u'MDT': u'Midnight ',
    u'MEC': u'MegaCoin',
    u'MED': u'MediterraneanCoin',
    u'MEGA': u'MegaFlash',
    u'MEME': u'Pepe',
    u'MER': u'Mercury',
    u'MET': u'Memessenger',
    u'METAL': u'MetalCoin',
    u'MG': u'Mind Gene',
    u'MGO': u'MobileGo',
    u'MI': u'XiaoMiCoin',
    u'MIL': u'Milllionaire Coin',
    u'MILO': u'MiloCoin',
    u'MIN': u'Minerals Coin',
    u'MINE': u'Instamine Nuggets',
    u'MINEX': u'Minex',
    u'MINT': u'MintCoin',
    u'MIS': u'MIScoin',
    u'MKR': u'Maker',
    u'MLITE': u'MeLite',
    u'MLN': u'Melon',
    u'MLS': u'CPROP',
    u'MM': u'MasterMint',
    u'MMC': u'MemoryCoin',
    u'MMNXT': u'MMNXT ',
    u'MMXIV': u'MaieutiCoin',
    u'MMXVI': u'MMXVI',
    u'MN': u'Cryptsy Mining Contract',
    u'MNC': u'MinCoin',
    u'MND': u'MindCoin',
    u'MNE': u'Minereum',
    u'MNM': u'Mineum',
    u'MNY': u'Monkey',
    u'MOD': u'Modum',
    u'MOIN': u'MoinCoin',
    u'MOJO': u'Mojocoin',
    u'MONA': u'MonaCoin',
    u'MONETA': u'Moneta',
    u'MONEY': u'MoneyCoin',
    u'MOON': u'MoonCoin',
    u'MOOND': u'Dark Moon',
    u'MOTO': u'Motocoin',
    u'MPRO': u'MediumProject',
    u'MRP': u'MorpheusCoin',
    u'MRS': u'MarsCoin',
    u'MRSA': u'MrsaCoin',
    u'MRT': u'MinersReward',
    u'MRV': u'Macroverse',
    u'MRY': u'MurrayCoin',
    u'MSC': u'MasterCoin',
    u'MSP': u'Mothership',
    u'MST': u'MustangCoin',
    u'MT': u'Mycelium Token',
    u'MTH': u'Monetha',
    u'MTL': u'Metal',
    u'MTR': u'MasterTraderCoin',
    u'MUDRA': u'MudraCoin',
    u'MUE': u'MonetaryUnit',
    u'MUSIC': u'Musiccoin',
    u'MUU': u'MilkCoin',
    u'MWC': u'MultiWallet Coin',
    u'MXT': u'MartexCoin',
    u'MYB': u'MyBit',
    u'MYC': u'MayaCoin',
    u'MYST': u'Mysterium',
    # u'MYST*': u'MysteryCoin',
    u'MZC': u'MazaCoin',
    u'N7': u'Number7',
    u'NAMO': u'NamoCoin',
    u'NAN': u'NanoToken',
    u'NANAS': u'BananaBits',
    u'NAS2': u'Nas2Coin',
    u'NAUT': u'Nautilus Coin',
    u'NAV': u'NavCoin',
    u'NBIT': u'NetBit',
    u'NBL': u'Nybble',
    u'NBT': u'NuBits',
    u'NDC': u'NeverDie',
    u'NDOGE': u'NinjaDoge',
    u'NEBL': u'Neblio',
    u'NEBU': u'Nebuchadnezzar',
    u'NEC': u'NeoCoin',
    u'NEF': u'NefariousCoin',
    u'NEO': u'NEO',
    u'NEOS': u'NeosCoin',
    u'NET': u'NetCoin',
    # u'NET*': u'Nimiq Exchange Token',
    u'NETC': u'NetworkCoin',
    u'NETKO': u'Netko',
    u'NEU': u'NeuCoin',
    u'NEVA': u'NevaCoin',
    u'NIC': u'NewInvestCoin',
    u'NICE': u'NiceCoin',
    u'NIMFA': u'Nimfamoney',
    u'NKA': u'IncaKoin',
    u'NKC': u'Nukecoinz',
    u'NKT': u'NakomotoDark',
    u'NLC': u'NoLimitCoin',
    u'NLC2': u'NoLimitCoin',
    u'NLG': u'Gulden',
    u'NMB': u'Nimbus Coin',
    u'NMC': u'NameCoin',
    u'NMR': u'Numerai',
    u'NOBL': u'NobleCoin',
    u'NODE': u'Node',
    u'NOO': u'Noocoin',
    u'NOTE': u'Dnotes',
    u'NPC': u'NPCcoin',
    u'NRB': u'NoirBits',
    u'NRC': u'Neurocoin',
    u'NRS': u'NoirShares',
    u'NSR': u'NuShares',
    u'NTC': u'NineElevenTruthCoin',
    u'NTCC': u'NeptuneClassic',
    u'NTM': u'NetM',
    u'NTO': u'Fujinto',
    u'NTRN': u'Neutron',
    u'NUBIS': u'NubisCoin',
    u'NUKE': u'NukeCoin',
    u'NUM': u'NumbersCoin',
    u'NVC': u'NovaCoin',
    u'NXC': u'Nexium',
    u'NXE': u'NXEcoin',
    u'NXS': u'Nexus',
    u'NXT': u'Nxt',
    u'NXTI': u'NXTI',
    u'NXTTY': u'NXTTY',
    u'NYAN': u'NyanCoin',
    u'NYC': u'NewYorkCoin',
    u'NZC': u'NewZealandCoin',
    u'OAX': u'OpenANX',
    u'OBITS': u'Obits Coin',
    u'OBS': u'Obscurebay',
    u'OC': u'OrangeCoin',
    u'OCL': u'Oceanlab',
    u'OCTO': u'OctoCoin',
    u'ODN': u'Obsidian',
    u'ODNT': u'Old Dogs New Tricks',
    u'OK': u'OKCash',
    u'OLDSF': u'OldSafeCoin',
    u'OLYMP': u'OlympCoin',
    u'OMA': u'OmegaCoin',
    u'OMC': u'OmniCron',
    u'OMG': u'OmiseGo',
    u'OMNI': u'Omni',
    u'ONION': u'DeepOnion',
    u'ONX': u'Onix',
    u'OPAL': u'OpalCoin',
    u'OPES': u'Opes',
    u'OPT': u'Opus',
    u'OPTION': u'OptionCoin',
    u'ORB': u'Orbitcoin',
    u'ORLY': u'OrlyCoin',
    u'ORME': u'Ormeus Coin',
    u'ORO': u'OroCoin',
    u'OS76': u'OsmiumCoin',
    u'OSC': u'OpenSourceCoin',
    u'OTX': u'Octanox',
    u'PAC': u'PacCoin',
    u'PAK': u'Pakcoin',
    u'PARA': u'ParanoiaCoin',
    u'PART': u'Particl',
    u'PASC': u'Pascal Coin',
    u'PASL': u'Pascal Lite',
    u'PAY': u'TenX',
    u'PAYP': u'PayPeer',
    u'PBC': u'PabyosiCoin',
    u'PBKX': u'Bankex',
    u'PBT': u'Primalbase',
    u'PCM': u'Procom',
    u'PCS': u'Pabyosi Coin',
    u'PDC': u'Project Decorum',
    u'PEC': u'PeaceCoin',
    # u'PEN': u'PenCoin',
    u'PEPECASH': u'Pepe Cash',
    u'PEX': u'PosEx',
    u'PGL': u'Prospectors',
    u'PHR': u'Phreak',
    u'PHS': u'PhilosophersStone',
    u'PIE': u'Persistent Information Exchange',
    u'PIGGY': u'Piggy Coin',
    u'PING': u'CryptoPing',
    u'PINK': u'PinkCoin',
    u'PINKX': u'PantherCoin',
    u'PIO': u'Pioneershares',
    u'PIRL': u'Pirl',
    u'PIVX': u'Private Instant Verified Transaction',
    u'PIX': u'Lampix',
    u'PIZZA': u'PizzaCoin',
    u'PKB': u'ParkByte',
    u'PLANET': u'PlanetCoin',
    u'PLBT': u'Polybius',
    u'PLNC': u'PLNCoin',
    u'PLR': u'Pillar',
    u'PLU': u'Pluton',
    u'PNC': u'PlatiniumCoin',
    u'PND': u'PandaCoin',
    u'PNK': u'SteamPunk',
    u'POE': u'Po.et',
    u'POINTS': u'Cryptsy Points',
    u'POLL': u'ClearPoll',
    u'POLY': u'PolyBit',
    u'POST': u'PostCoin',
    u'POSW': u'PoSWallet',
    u'POT': u'PotCoin',
    u'POWR': u'Power Ledger',
    u'PPC': u'PeerCoin',
    u'PPP': u'PayPie',
    u'PPT': u'Populous',
    u'PPY': u'Peerplays',
    u'PQT': u'PAquarium',
    u'PRC': u'ProsperCoin',
    u'PRE': u'Premium',
    u'PRES': u'President Trump',
    u'PRG': u'Paragon',
    u'PRIME': u'PrimeChain',
    u'PRM': u'PrismChain',
    u'PRO': u'Propy',
    u'PROC': u'ProCurrency',
    u'PRX': u'Printerium',
    u'PSB': u'PesoBit',
    u'PSEUD': u'PseudoCash',
    u'PSI': u'PSIcoin',
    u'PST': u'Primas',
    u'PSY': u'Psilocybin',
    u'PTA': u'PentaCoin',
    u'PTC': u'PesetaCoin',
    u'PTOY': u'Patientory',
    # u'PTS*': u'Protoshares',
    u'PULSE': u'Pulse',
    u'PUPA': u'PupaCoin',
    u'PUT': u'PutinCoin',
    u'PWR': u'PowerCoin',
    u'PX': u'PXcoin',
    u'PXC': u'PhoenixCoin',
    u'PXI': u'Prime-X1',
    u'PXL': u'Phalanx',
    u'PYC': u'PayCoin',
    u'QAU': u'Quantum',
    u'QBC': u'Quebecoin',
    u'QBK': u'QuBuck Coin',
    u'QBT': u'Cubits',
    u'QCN': u'Quazar Coin',
    u'QORA': u'QoraCoin',
    u'QRK': u'QuarkCoin',
    u'QRL': u'Quantum Resistant Ledger',
    u'QSLV': u'Quicksilver coin',
    u'QTL': u'Quatloo',
    u'QTUM': u'QTUM',
    u'QTZ': u'Quartz',
    u'QVT': u'Qvolta',
    u'QWARK': u'Qwark',
    u'R': u'Revain',
    u'RADI': u'RadicalCoin',
    u'RADS': u'Radium',
    u'RAIN': u'Condensate',
    u'RATIO': u'Ratio',
    u'RBIES': u'Rubies',
    u'RBIT': u'ReturnBit',
    u'RBR': u'Ribbit Rewards',
    u'RBT': u'Rimbit',
    u'RBX': u'RiptoBuX',
    u'RBY': u'RubyCoin',
    u'RC': u'Russiacoin',
    u'RCC': u'Reality Clash',
    u'RCN': u'Ripio',
    # u'RCN*': u'RCoin',
    u'RCX': u'RedCrowCoin',
    u'RDD': u'ReddCoin',
    u'RDN': u'RadonPay',
    u'REA': u'Realisto',
    u'REAL': u'REAL',
    u'REC': u'Regalcoin',
    u'RED': u'Redcoin',
    u'REE': u'ReeCoin',
    u'REP': u'Augur',
    u'REQ': u'Request Network',
    u'REV': u'Revenu',
    u'REX': u'REX',
    u'RGC': u'RG Coin',
    u'RIC': u'Riecoin',
    u'RICE': u'RiceCoin',
    u'RIDE': u'Ride My Car',
    u'RING': u'RingCoin',
    u'RIPO': u'RipOffCoin',
    u'RISE': u'Rise',
    u'RIYA': u'Etheriya',
    u'RKC': u'Royal Kingdom Coin',
    u'RLC': u'iEx.ec',
    u'RMS': u'Resumeo Shares',
    u'RNC': u'ReturnCoin',
    u'RNS': u'RenosCoin',
    u'ROOT': u'RootCoin',
    u'ROOTS': u'RootProject',
    u'ROS': u'ROS Coin',
    u'ROUND': u'RoundCoin',
    u'ROYAL': u'RoyalCoin',
    u'RPC': u'RonPaulCoin',
    u'RRT': u'Recovery Right Tokens',
    u'RT2': u'RotoCoin',
    u'RUBIT': u'Rublebit',
    u'RUP': u'Rupee',
    u'RUST': u'RustCoin',
    u'RVT': u'Rivetz',
    u'RYC': u'RoyalCoin',
    u'RYCN': u'RoyalCoin 2.0',
    u'RZR': u'RazorCoin',
    u'S8C': u'S88 Coin',
    u'SAFEX': u'SafeExchangeCoin',
    u'SAK': u'SharkCoin',
    u'SALT': u'Salt Lending',
    u'SAN': u'Santiment',
    u'SAND': u'BeachCoin',
    u'SANDG': u'Save and Gain',
    # u'SAR': u'SARCoin',
    u'SAT2': u'Saturn2Coin',
    u'SBC': u'StableCoin',
    # u'SBD': u'Steem Backed Dollars',
    u'SC': u'Siacoin',
    u'SCASH': u'SpaceCash',
    u'SCL': u'Social Nexus',
    u'SCN': u'Swiscoin',
    u'SCORE': u'Scorecoin',
    u'SCOT': u'Scotcoin',
    u'SCRPT': u'ScryptCoin',
    u'SCRT': u'SecretCoin',
    u'SCT': u'ScryptToken',
    u'SDC': u'ShadowCash',
    u'SDP': u'SydPakCoin',
    u'SEEDS': u'SeedShares',
    u'SEL': u'SelenCoin',
    u'SEN': u'Sentaro',
    u'SEQ': u'Sequence',
    u'SFC': u'Solarflarecoin',
    u'SFE': u'Safecoin',
    u'SFR': u'SaffronCoin',
    u'SH': u'Shilling',
    u'SHADE': u'ShadeCoin',
    u'SHIFT': u'Shift',
    u'SHLD': u'ShieldCoin',
    u'SHORTY': u'ShortyCoin',
    u'SIB': u'SibCoin',
    u'SIFT': u'Smart Investment Fund Token',
    u'SIGT': u'Signatum',
    u'SIGU': u'Singular',
    u'SILK': u'SilkCoin',
    u'SJCX': u'StorjCoin',
    u'SKB': u'SkullBuzz',
    u'SKIN': u'Skincoin',
    u'SKY': u'Skycoin',
    u'SLG': u'SterlingCoin',
    u'SLING': u'Sling Coin',
    u'SLM': u'SlimCoin',
    u'SLR': u'SolarCoin',
    # u'SLS': u'SaluS',
    u'SMAC': u'Social Media Coin',
    u'SMART': u'SmartCash',
    u'SMC': u'SmartCoin',
    u'SMF': u'SmurfCoin',
    u'SMLY': u'SmileyCoin',
    u'SMSR': u'Samsara Coin',
    u'SMT': u'Social Media Market',
    u'SNC': u'SunContract',
    u'SND': u'Sandcoin',
    u'SNGLS': u'SingularDTV',
    u'SNM': u'SONM',
    u'SNRG': u'Synergy',
    u'SNT': u'Status Network Token',
    u'SOCC': u'SocialCoin',
    u'SOIL': u'SoilCoin',
    u'SOJ': u'Sojourn Coin',
    u'SOLE': u'SoleCoin',
    u'SONG': u'Song Coin',
    u'SOON': u'SoonCoin',
    u'SOUL': u'SoulCoin',
    u'SP': u'Sex Pistols',
    u'SPA': u'SpainCoin',
    u'SPACE': u'SpaceCoin',
    u'SPC': u'SpinCoin',
    u'SPEC': u'SpecCoin',
    u'SPHR': u'Sphere Coin',
    u'SPKTR': u'Ghost Coin',
    u'SPM': u'Supreme',
    u'SPN': u'Spoon',
    u'SPORT': u'SportsCoin',
    u'SPOTS': u'Spots',
    u'SPR': u'Spreadcoin',
    u'SPRTS': u'Sprouts',
    u'SPT': u'Spots',
    u'SPX': u'Specie',
    u'SQL': u'Squall Coin',
    u'SRC': u'SecureCoin',
    u'SSD': u'Sonic Screw Driver Coin',
    u'SSTC': u'SunShotCoin',
    u'SSV': u'SSVCoin',
    u'STA': u'Starta',
    # u'STA*': u'Stakers',
    u'STALIN': u'StalinCoin',
    u'STAR': u'Starbase',
    # u'STAR*': u'StarCoin',
    u'START': u'StartCoin',
    u'STCN': u'Stakecoin',
    u'STEEM': u'Steem',
    u'STEPS': u'Steps',
    u'STHR': u'Stakerush',
    u'STO': u'Save The Ocean',
    u'STORJ': u'Storj',
    u'STR*': u'StarCoin',
    u'STRAT': u'Stratis',
    u'STS': u'STRESScoin',
    u'STU': u'BitJob',
    u'STV': u'Sativa Coin',
    u'STX': u'Stox',
    u'SUB': u'Substratum Network',
    # u'SUB*': u'Subscriptio',
    u'SUMO': u'Sumokoin',
    u'SUP': u'Supcoin',
    u'SUPER': u'SuperCoin',
    u'SUR': u'Suretly',
    u'SWARM': u'SwarmCoin',
    u'SWEET': u'SweetStake',
    u'SWIFT': u'BitSwift',
    u'SWING': u'SwingCoin',
    u'SWT': u'Swarm City Token',
    u'SXC': u'SexCoin',
    u'SYNC': u'SyncCoin',
    u'SYNX': u'Syndicate',
    u'SYS': u'SysCoin',
    u'TAAS': u'Token as a Service',
    u'TAB': u'MollyCoin',
    u'TAG': u'TagCoin',
    u'TAGR': u'Think And Get Rich Coin',
    u'TAJ': u'TajCoin',
    u'TAK': u'TakCoin',
    u'TAM': u'TamaGucci',
    u'TAP': u'TappingCoin',
    u'TBCX': u'TrashBurn',
    u'TCR': u'Thecreed',
    u'TDFB': u'TDFB',
    u'TEAM': u'TeamUP',
    u'TEC': u'TeCoin',
    u'TECH': u'TechCoin',
    u'TEK': u'TekCoin',
    u'TELL': u'Tellurion',
    u'TENNET': u'Tennet',
    u'TER': u'TerraNovaCoin',
    u'TES': u'TeslaCoin',
    u'TESLA': u'TeslaCoilCoin',
    u'TFL': u'True Flip Lottery',
    u'TGC': u'TigerCoin',
    u'THC': u'The Hempcoin',
    u'THNX': u'ThankYou',
    u'THS': u'TechShares',
    u'TIA': u'Tianhe',
    u'TIC': u'TrueInvestmentCoin',
    u'TIE': u'Ties Network',
    u'TIME': u'Time',
    u'TIT': u'TitCoin',
    u'TIX': u'Blocktix',
    u'TKN': u'TokenCard  ',
    u'TKN*': u'TrollTokens',
    u'TKR': u'CryptoInsight',
    u'TKS': u'Tokes',
    u'TMC': u'TimesCoin',
    u'TME': u'Timereum',
    u'TNT': u'Tierion',
    u'TODAY': u'TodayCoin',
    u'TOM': u'Tomahawkcoin',
    u'TOR': u'TorCoin',
    u'TOT': u'TotCoin',
    u'TPAY': u'TrollPlay',
    u'TPG': u'Troll Payment',
    u'TRA': u'Tetra',
    u'TRC': u'TerraCoin',
    u'TRI': u'Triangles Coin',
    u'TRICK': u'TrickyCoin',
    u'TRIG': u'Trigger',
    u'TRK': u'TruckCoin',
    u'TRON': u'Positron',
    u'TRST': u'TrustCoin',
    u'TRUMP': u'TrumpCoin',
    u'TRUST': u'TrustPlus',
    u'TRV': u'Travel Coin',
    u'TRX': u'Tronix',
    u'TSE': u'TattooCoin',
    u'TTC': u'TittieCoin',
    u'TUR': u'Turron',
    u'TWIST': u'TwisterCoin',
    u'TWLV': u'Twelve Coin',
    u'TX': u'Transfer',
    u'TZC': u'TrezarCoin',
    u'U': u'Ucoin',
    u'UBIQ': u'Ubiqoin',
    u'UBQ': u'Ubiq',
    u'UET': u'Useless Ethereum Token',
    u'UFO': u'UFO Coin',
    u'UIS': u'Unitus',
    u'ULTC': u'Umbrella',
    u'UMC': u'Umbrella Coin',
    u'UNAT': u'Unattanium',
    u'UNB': u'UnbreakableCoin',
    u'UNC': u'UnCoin',
    u'UNF': u'Unfed Coin',
    u'UNI': u'Universe',
    u'UNIFY': u'Unify',
    u'UNIQ': u'Uniqredit',
    u'UNIT': u'Universal Currency',
    u'UNITS': u'GameUnits',
    u'UNITY': u'SuperNET',
    u'UNO': u'Unobtanium',
    u'UR': u'UR',
    u'URO': u'UroCoin',
    u'USC': u'Ultimate Secure Cash',
    u'USDE': u'UnitaryStatus Dollar',
    u'USDT': u'Tether',
    u'UTC': u'UltraCoin',
    u'UTH': u'Uther',
    u'UTIL': u'Utility Coin',
    u'VAPOR': u'Vaporcoin',
    u'VDO': u'VidioCoin',
    u'VEC2': u'VectorCoin 2.0 ',
    u'VEG': u'BitVegan',
    u'VEN': u'Vechain',
    u'VERI': u'Veritaseum',
    u'VERSA': u'Versa Token',
    u'VIA': u'ViaCoin',
    u'VIB': u'Viberate',
    u'VIBE': u'VIBEHub',
    u'VIDZ': u'PureVidz',
    u'VIOR': u'ViorCoin',
    u'VIP': u'VIP Tokens',
    u'VIRAL': u'Viral Coin',
    u'VISIO': u'Visio',
    u'VIVO': u'VIVO Coin',
    u'VLT': u'Veltor',
    u'VLTC': u'VaultCoin',
    u'VMC': u'VirtualMining Coin',
    u'VOISE': u'Voise',
    u'VOLT': u'BitVolt',
    u'VOOT': u'VootCoin',
    u'VOX': u'Voxels',
    u'VOYA': u'Voyacoin',
    u'VPRC': u'VapersCoin',
    u'VRC': u'VeriCoin',
    u'VRM': u'Verium',
    u'VRS': u'Veros',
    u'VSL': u'vSlice',
    u'VSX': u'Vsync',
    u'VTA': u'VirtaCoin',
    u'VTC': u'VertCoin',
    u'VTR': u'Vtorrent',
    u'VTX': u'Vertex',
    u'VTY': u'Victoriouscoin',
    u'VUC': u'Virta Unique Coin',
    u'WARP': u'WarpCoin',
    u'WASH': u'WashingtonCoin',
    u'WAVES': u'Waves',
    u'WAY': u'WayCoin',
    u'WBB': u'Wild Beast Coin',
    u'WBTC': u'wBTC',
    u'WC': u'WhiteCoin',
    u'WCT': u'Waves Community Token',
    u'WDC': u'WorldCoin',
    u'WEALTH': u'WealthCoin',
    u'WEX': u'Wexcoin',
    u'WGC': u'World Gold Coin',
    u'WGO': u'WavesGO',
    u'WGR': u'Wagerr',
    u'WIC': u'Wi Coin',
    u'WILD': u'Wild Crypto',
    u'WINE': u'WineCoin',
    u'WINGS': u'Wings DAO',
    u'WINK': u'Wink',
    u'WISC': u'WisdomCoin',
    u'WMC': u'WMCoin',
    u'WNET': u'Wavesnode.net',
    u'WOLF': u'Insanity Coin',
    u'WOLK': u'Wolk',
    u'WOMEN': u'WomenCoin',
    u'WOP': u'WorldPay',
    u'WORM': u'HealthyWorm',
    u'WRC': u'Worldcore',
    # u'WRC*': u'WarCoin',
    u'WRT': u'WRTcoin',
    u'WSX': u'WeAreSatoshi',
    u'WTC': u'Waltonchain',
    u'WTT': u'Giga Watt',
    u'X2': u'X2Coin',
    u'XAI': u'SapienceCoin',
    # u'XAU': u'XauCoin',
    u'XAUR': u'Xaurum',
    u'XBC': u'BitcoinPlus',
    u'XBOT': u'SocialXbotCoin',
    u'XBS': u'Bitstake',
    u'XBTS': u'Beats',
    u'XBY': u'XtraBYtes',
    u'XC': u'X11 Coin',
    u'XCASH': u'Xcash',
    u'XCE': u'Cerium',
    u'XCI': u'Cannabis Industry Coin',
    u'XCN': u'Cryptonite',
    u'XCO': u'XCoin',
    u'XCP': u'CounterParty',
    u'XCR': u'Crypti',
    u'XCRE': u'Creatio',
    u'XCT': u'C-Bits',
    u'XCXT': u'CoinonatX',
    u'XDB': u'DragonSphere',
    u'XDE2': u'XDE II',
    u'XDN': u'DigitalNote ',
    u'XDP': u'DogeParty',
    u'XDQ': u'Dirac Coin',
    u'XEL': u'Elastic',
    u'XEM': u'NEM',
    u'XEN': u'XenixCoin',
    u'XFC': u'Forever Coin',
    u'XG': u'XG Sports',
    u'XGB': u'GoldenBird',
    u'XGR': u'GoldReserve',
    u'XHI': u'HiCoin',
    u'XID': u'Sphre AIR',
    # u'XID*': u'International Diamond Coin',
    u'XIOS': u'Xios',
    u'XJO': u'JouleCoin',
    u'XLB': u'LibertyCoin',
    u'XLC': u'LeviarCoin',
    u'XLM': u'Stellar',
    u'XLR': u'Solaris',
    u'XMCC': u'MonacoCoin',
    u'XMG': u'Coin Magi',
    u'XMR': u'Monero',
    u'XMS': u'Megastake',
    u'XMY': u'MyriadCoin',
    u'XNA': u'DeOxyRibose',
    u'XNC': u'XenCoin',
    u'XNG': u'Enigma',
    u'XNX': u'XanaxCoin',
    u'XP': u'XP',
    u'XPB': u'Pebble Coin',
    u'XPD': u'PetroDollar',
    u'XPH': u'PharmaCoin',
    u'XPM': u'PrimeCoin',
    u'XPO': u'Opair',
    u'XPOKE': u'PokeChain',
    u'XPRO': u'ProCoin',
    u'XPS': u'PoisonIvyCoin',
    u'XPY': u'PayCoin',
    u'XQN': u'Quotient',
    u'XRA': u'Ratecoin',
    u'XRB': u'RaiBlocks',
    u'XRE': u'RevolverCoin',
    u'XRL': u'Rialto.AI',
    u'XRP': u'Ripple',
    u'XSEED': u'BitSeeds',
    u'XSI': u'Stability Shares',
    u'XSP': u'PoolStamp',
    u'XSPEC': u'Spectre',
    u'XST': u'StealthCoin',
    u'XT': u'ExtremeCoin',
    u'XTC': u'TileCoin',
    u'XTZ': u'Tezos',
    u'XUC': u'Exchange Union',
    u'XUP': u'UPcoin',
    u'XVC': u'Vcash',
    u'XVE': u'The Vegan Initiative',
    u'XVG': u'Verge',
    u'XVP': u'VirtacoinPlus',
    u'XWC': u'WhiteCoin',
    u'XWT': u'World Trade Funds',
    u'XXX': u'XXXCoin',
    u'XZC': u'ZCoin',
    u'YAC': u'YAcCoin',
    u'YAY': u'YAYcoin',
    u'YBC': u'YbCoin',
    u'YES': u'YesCoin',
    u'YMC': u'YamahaCoin',
    u'YOC': u'YoCoin',
    u'YOVI': u'YobitVirtualCoin',
    u'YOYOW': u'Yoyow',
    u'ZBC': u'Zilbercoin',
    u'ZCC': u'ZCC Coin',
    u'ZCL': u'ZClassic',
    u'ZEC': u'ZCash',
    u'ZECD': u'ZCashDarkCoin',
    u'ZED': u'ZedCoins',
    u'ZEIT': u'ZeitCoin',
    u'ZEN': u'ZenCash',
    u'ZENI': u'Zennies',
    u'ZER': u'Zero',
    u'ZET': u'ZetaCoin',
    u'ZET2': u'Zeta2Coin',
    u'ZLQ': u'ZLiteQubit',
    u'ZNE': u'ZoneCoin',
    u'ZNY': u'BitZeny',
    u'ZOI': u'Zoin',
    u'ZOOM': u'ZoomCoin',
    u'ZRC': u'ZrCoin',
    # u'ZRC*': u'ZiftrCoin',
    u'ZRX': u'0x',
    u'ZSC': u'Zeusshield',
    u'ZSE': u'ZSEcoin',
    u'ZUR': u'Zurcoin',
    u'ZXT': u'Zcrypt',
    u'ZYD': u'ZayedCoin',
}

# ----------------------------------------------------------------------
# Help/support URLs
# ----------------------------------------------------------------------
HELP_URL = 'https://github.com/giovannicoppola/alfred-convert/issues'
README_URL = 'https://github.com/giovannicoppola/alfred-convert#alfred-convert'

# ----------------------------------------------------------------------
# Icons
# ----------------------------------------------------------------------
ICON_CURRENCY = 'icons/money.png'
ICON_HELP = 'icons/help.png'
ICON_UPDATE = 'icons/update-available.png'

# ----------------------------------------------------------------------
# Update and default user settings
# ----------------------------------------------------------------------

DEFAULT_SETTINGS = {}


def bootstrap(wf):
    """Copy default files to user data if necessary.

    Args:
        wf (Workflow3): Active `Workflow3` object.

    """
    filepaths = [
        (wf.datafile(CUSTOM_DEFINITIONS_FILENAME),
         wf.workflowfile(CUSTOM_DEFINITIONS_FILENAME + '.sample')),
        (wf.datafile(ACTIVE_CURRENCIES_FILENAME),
         wf.workflowfile(ACTIVE_CURRENCIES_FILENAME + '.default')),
    ]

    for path, default in filepaths:
        if not os.path.exists(path):
            shutil.copy(default, path)
